#macdrawer: provides custom drawer windows for Tk-Cocoa. The macdrawer.tcl file provides the public interface; macsheet.m provides the platform-specific primitives for displaying and hiding the drawer.  (c) 2010 Kevin Walzer/WordTech Communications LLC. See the file "license.terms" for information on usage and redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES. 


namespace eval macdrawer {

    if {![info exists library]} {
	variable library [file dirname [info script]]
    }

    load [file join $library libmacdrawer1.0.dylib]

    
    variable drawerwindow

    #create the window, set drawer style, and move offscreen

    set drawerwindow .drawer
    toplevel $drawerwindow
    tk::unsupported::MacWindowStyle style $drawerwindow drawer 
    wm geometry $drawerwindow +10000+10000


    #main process displaying sheet
    proc drawer {parent} {

	variable drawerwindow

	#set the drawer window as a child of the parent window: Cocoa method of grouping, allows drawer window to be attached to parent window
	[namespace current]::makedrawer $parent $drawerwindow

	#place and display the window correctly
	set parentx [winfo rootx $parent]
	set parenty [winfo rooty $parent]
	set targetx [expr $parentx - [winfo width $drawerwindow]]
     	set drawerheight [expr {int([winfo height $parent] * .5)}]
    	set drawerheight [winfo reqheight $drawerwindow]
     	set parentheight [winfo height $parent]
     	set interimgap [expr $parentheight - $drawerheight]
     	set finalgap [expr $interimgap/2]
     	set targety [expr [winfo y $parent] + $finalgap]

	wm geometry $drawerwindow +$targetx+$targety

    }


    #close the drawer
    proc closedrawer {parent} {

	variable drawerwindow

	#detatch the window from its parent
	[namespace current]::removedrawer $parent $drawerwindow

	#move it out of the way offscreen
	wm geometry $drawerwindow +10000+10000

    }

    
    #toggle the door open/closed
    proc toggle {parent} {

	variable drawerwindow

	#check placement of window: if offscreen it should be rendered as drawer
	if {[winfo rootx $drawerwindow] >= 10000} {

	    [namespace current]::drawer $parent 

	} else {

	    [namespace current]::closedrawer $parent 

	}
    }
    
    namespace export *
}

